@@ -130,15 +130,17 @@ monthlyWB <- function(AWC, PPT, PET, S_init = AWC, starting_month = 1, rep = 1,
 
 #' @title Visualize Monthly Water Balance
 #' 
-#' @description This function offers one possible visualization for the results of \code{monthlyWB}.
+#' @description This function offers one possible visualization for the results of `monthlyWB`.
 #' 
-#' @author D.E. Beaudette
+#' @note You may have to adjust figure margins and size to get all of the elements to "look right".
+#' 
+#' @author D.E. Beaudette and J.M. Skovlin
 #' 
 #' @param WB output from \code{monthlyWB}
 #' 
 #' @param AWC available water-holding capacity (mm)
 #' 
-#' @param fig.title a title
+#' @param showAWC styling to show box for AWC below (default) or above zero point of axis
 #'
 #' @param sw.col color for soil water
 #' 
@@ -148,19 +150,60 @@ monthlyWB <- function(AWC, PPT, PET, S_init = AWC, starting_month = 1, rep = 1,
 #' 
 #' @param deficit.col color for deficit
 #' 
-#' @param pch plotting character for points (default: 22)
+#' @param pch plotting character for PPT and PET points (`c('P', 'E')`)
 #' 
-#' @param pt.cex character expansion factor for points (default: 1)
+#' @param pt.cex character expansion factor for PPT and PET points
 #' 
-#' @param lwd line width (default: 1)
+#' @param lwd line width for PPT and PET curves
+#' 
+#' @param n.ticks approximate number of tick marks on positive and negative y-axis
+#' 
+#' @param grid.col horizontal grid line color
+#' 
+#' @param month.cex character expansion factor for month labels (x-axis)
 #' 
 #' @keywords hplots
 #' 
-plotWB <- function(WB, AWC, fig.title='', sw.col='#377EB8', surplus.col='#4DAF4A', et.col='#E41A1C', deficit.col='#FF7F00', pch = 22, pt.cex = 1, lwd = 1) {
+#' @examples 
+#' 
+#' if(requireNamespace('hydromad')) {
+#' 
+#' ## 100mm (4") AWC
+#' # monthly PPT and PET extracted from monthly estimates at Sonora, CA
+#' AWC <- 100
+#' PPT <- c(171, 151, 138, 71, 36, 7, 1, 2, 11, 48, 102, 145)
+#' PET <- c(15.17, 18.26, 30.57, 42.95, 75.37, 108.05, 139.74, 128.9, 93.99, 59.84, 26.95, 14.2)
+#' 
+#' # water-year
+#' # three years
+#' x.wb <- monthlyWB(AWC, PPT, PET, S_init = 0, starting_month = 9, rep = 3)
+#' x.wb[x.wb$mo == 'Sep', ]
+#' 
+#' # new-style representation, with AWC "above 0"
+#' plotWB(x.wb, AWC, showAWC = 'below')
+#' 
+#' # old-style representation, with AWC "above 0"
+#' plotWB(x.wb, AWC, showAWC = 'above')
+#' 
+#' 
+#' # water year
+#' # last iteration
+#' x.wb <- monthlyWB(AWC, PPT, PET, S_init = 0, 
+#'                   starting_month = 9, rep = 3, 
+#'                   keep_last = TRUE
+#' )
+#' 
+#' plotWB(x.wb, AWC)
+#' 
+#' }
+#' 
+plotWB <- function(WB, AWC, showAWC = 'below', sw.col = '#377EB8', surplus.col = '#4DAF4A', et.col = '#E41A1C', deficit.col = '#FF7F00', pch = c('P', 'E'), pt.cex = 0.85, lwd = 2, n.ticks = 8, grid.col = grey(0.65), month.cex = 1) {
   
   # number of time steps, usually months
   n <- nrow(WB)
   
+  if (showAWC == 'above') {
+  
   # left-side vertical scales
   # y.axt <- pretty(c(AWC + WB$U, WB$PPT, 0 - WB$PET), n = 15)
   y.min <- min(- WB$PET)
@@ -171,8 +214,8 @@ plotWB <- function(WB, AWC, fig.title='', sw.col='#377EB8', surplus.col='#4DAF4A
   
   # specific axis
   # surplus.axis <- pretty(WB$U, n = 5)
-  ppt.axis <- pretty(c(0, ppt.awc.max), n = 5)
-  pet.axis <- pretty(WB$PET, n = 5)
+  ppt.axis <- pretty(c(0, ppt.awc.max), n = n.ticks)
+  pet.axis <- pretty(WB$PET, n = n.ticks)
   
   # remove '0' from surplus and pet axes
   pet.axis <- pet.axis[pet.axis != 0]
@@ -185,7 +228,9 @@ plotWB <- function(WB, AWC, fig.title='', sw.col='#377EB8', surplus.col='#4DAF4A
   # init canvas
   plot(1, 1, type='n', ylim=c(y.min, y.max), xlim=c(0, max(bp)),  axes=FALSE, ylab='', xlab='')
   
-  # segments(x0=0, y0=y.axt, x1=max(bp), y1=y.axt, lty=2, col=grey(0.45))
+  # horizontal helper lines
+  segments(x0 = 0, y0 = ppt.axis, x1 = max(bp), y1 = ppt.axis, lty = 2, col = grid.col)
+  segments(x0 = 0, y0 = -pet.axis, x1 = max(bp), y1 = -pet.axis, lty=2, col = grid.col)
   
   # plot surplus
   barplot(AWC + WB$U, axes=FALSE, ylab='', xlab='', col=surplus.col, border=NA, add=TRUE)
@@ -208,6 +253,62 @@ plotWB <- function(WB, AWC, fig.title='', sw.col='#377EB8', surplus.col='#4DAF4A
   # annotate AWC
   rect(xleft = 0.2, ybottom = 0, xright = n + (n * 0.2), ytop = AWC)
   
+  } 
+  
+if(showAWC == 'below') {
+  
+  # left-side vertical scales
+  # y.min <- min(- WB$PET - AWC/2)
+  # y.max <- max(AWC/2 + WB$U)
+  
+  y.min <- min(c(- WB$PET, - AWC))
+  y.max <- max(c(WB$U, WB$PPT, WB$PET))
+  
+  # specific axis
+  ppt.axis <- pretty(c(0, y.max), n = n.ticks)
+  pet.axis <- pretty(c(0, (0 - y.min)), n = n.ticks)
+  
+  # remove '0' from surplus and pet axes
+  pet.axis <- pet.axis[pet.axis != 0]
+  # surplus.axis <- surplus.axis[surplus.axis != 0]
+  
+  # init barplot x-axis
+  bp <- barplot(AWC + WB$S, plot=FALSE)
+  bp <- as.vector(bp)
+  
+  # init canvas
+  plot(1, 1, type='n', ylim=c(y.min, y.max), xlim=c(0, max(bp)),  axes=FALSE, ylab='', xlab='')
+  
+  # horizontal helper lines
+  segments(x0 = 0, y0 = ppt.axis, x1 = max(bp), y1 = ppt.axis, lty = 2, col = grid.col)
+  segments(x0 = 0, y0 = -pet.axis, x1 = max(bp), y1 = -pet.axis, lty=2, col = grid.col)
+  
+  # overlay AWC with white to erase surplus within AWC
+  barplot(rep((0 - AWC), times=n), axes=FALSE, col=par('bg'), border=NA, add=TRUE)
+  
+  # add deficit
+  barplot((0 - WB$E) + WB$D, axes=FALSE, col=deficit.col, border=NA, add=TRUE)
+  
+  # overlay soil water
+  barplot((0 - WB$S), axes=FALSE, col=sw.col, border=NA, add=TRUE)
+  
+  # utilization of soil water
+  # barplot(WB$u_i, axes=FALSE, col='orange', border=NA, add=TRUE)
+  
+  # overlay actual PET
+  barplot(WB$PET, axes=FALSE, col=et.col, border=NA, add=TRUE)
+  
+  # overlay actual ET
+  #barplot(WB$E, axes=FALSE, col=aet.col, border=NA, add=TRUE)
+  
+  # plot surplus
+  barplot(WB$U, axes=FALSE, ylab='', xlab='', col=surplus.col, border=NA, add=TRUE)
+  
+  # annotate AWC
+  rect(xleft = 0.2, ybottom = (0 - AWC), xright = n + (n * 0.2), ytop = 0)
+  
+} 
+  
   # left-hand axes
   combined.at <- c(-pet.axis, ppt.axis)
   combined.lab <- c(pet.axis, ppt.axis)
@@ -221,25 +322,28 @@ plotWB <- function(WB, AWC, fig.title='', sw.col='#377EB8', surplus.col='#4DAF4A
   # mtext(text = 'PPT | Soil Water', side = 2, line = 2.25, at=10, adj=0, cex=0.85, font=2)
   # mtext(text = 'Surplus', side = 4, line = 2.25, at=y.max, adj=1, cex=0.85, font=2)
   # negative side
-  mtext(text = 'PET | ET | Deficit | Soil Water | Surplus     (mm)', side = 2, line = 2.25, cex=0.85, font=2)
+  mtext(text = 'Soil Water | Deficit | Surplus | PET | ET    (mm)', side = 2, line = 2.25, cex=0.85, font=2)
   
   # annotate AWC
-  text(x=0, y=AWC/2, labels = sprintf("AWC: %smm", AWC), srt=90, cex=0.85, font=1)
+  mtext(sprintf("AWC: %smm", AWC), side = 3, at = 0, cex = 0.85, font = 3, adj = 0)
   
-  # month axis
-  axis(side = 1, at = bp, labels = WB$mo, line=0, tick = FALSE, font=2)
+  # month axis: no line, just ticks
+  axis(side = 1, at = bp, labels = WB$mo, line = 0, tick = TRUE, font = 2, cex = month.cex, col = NA, col.ticks = par('fg'))
   
-  # add PPT and PET series
-  lines(bp, WB$PPT, type='l', col=par('fg'), lwd = lwd)
-  points(bp, WB$PPT, col=par('bg'), bg=par('fg'), pch = pch, cex = pt.cex)
-  lines(bp, 0 - WB$PET, type='l', col=par('fg'), lwd = lwd)
-  points(bp, 0 - WB$PET, col=par('bg'), bg=par('fg'), pch = pch, cex = pt.cex)
+  # using a bg-colored plotting symbol to paint behind PPT and PET plotting symbols
+  # must be a little smaller than the symbol
+  bg.cex <- strheight(pch[1], font = 2, cex = pt.cex) / 6
+  
+  # PPT
+  points(bp, WB$PPT, col=par('bg'), pch = 15, cex = bg.cex)
+  lines(bp, WB$PPT, type='b', col=par('fg'), lwd = lwd, pch = pch[1], cex = pt.cex, font = 2)
+  
+  # PET
+  points(bp, 0 - WB$PET, col=par('bg'), pch = 15, cex = bg.cex)
+  lines(bp, 0 - WB$PET, type='b', col=par('fg'), lwd = lwd, pch = pch[2], cex = pt.cex, font = 2)
   
   # legend
-  legend(x=max(bp), y=y.max, horiz = TRUE, legend=c('Soil Water', 'Surplus', 'ET', 'Deficit'), col=c(sw.col, surplus.col, et.col, deficit.col), pch = 15, bty='n', pt.cex = 1.5, xpd=NA, cex=1.125, xjust = 1, yjust=0)
-  
-  # title
-  mtext(fig.title, side = 3, adj=0, at=-0.5, cex=1.5, font=2)
+  legend(x = max(bp), y = y.max, horiz = TRUE, legend = c('Soil Water', 'Surplus', 'ET', 'Deficit'), col = c(sw.col, surplus.col, et.col, deficit.col), pch = 15, bty='n', pt.cex = 1.5, xpd = NA, cex = 1.125, xjust = 1, yjust = -0.25)
   
 }
 
